<template>
  <div class="app-container">
    <el-form
      :model="queryParams"
      ref="queryForm"
      size="small"
      :inline="true"
      v-show="showSearch"
      label-width="110px"
    >
      <el-row>
        <el-col :span="6">
          <el-form-item
            label="交款员"
            prop="tollCollectorName"
            style="display: flex"
          >
            <el-select
              v-model="queryParams.tollCollectorName"
              filterable
              placeholder="请选择交款员"
              clearable
              @clear="getCompanyList"
              @change="idFn"
            >
              <el-option
                v-for="dict in CompanyList"
                :key="dict.userId"
                :label="dict.nickName"
                :value="dict.userId"
              />
            </el-select>
          </el-form-item>
        </el-col>
        <el-col :span="14">
          <el-form-item
            label="交账时间"
            prop="tollCollectorName"
            style="display: flex"
          >
            <el-date-picker
              v-model="value1"
              type="datetimerange"
              :picker-options="pickerOptions"
              :default-time="['00:00:00', '23:59:00']"
              format="yyyy-MM-dd HH:mm"
              value-format="yyyy-MM-dd HH:mm"
              start-placeholder="起止日期"
              end-placeholder="终止日期"
            >
            </el-date-picker>
          </el-form-item>
        </el-col>
        <el-col :span="3">
          <el-form-item>
            <el-button
              type="primary"
              icon="el-icon-search"
              size="mini"
              @click="handleQuery"
              >搜索</el-button
            >
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button icon="el-icon-edit" size="mini" @click="handleDelete"
          >撤销</el-button
        >
      </el-col>
      <el-col :span="1.5">
        <el-button icon="el-icon-edit" size="mini" @click="handledocument"
          >补打单据</el-button
        >
      </el-col>
    </el-row>

    <el-table
      :row-class-name="tableRowClassName"
      style="width: 80%"
      :data="tableData"
      @selection-change="handleSelect"
      ref="multipleTable"
      border
    >
      <el-table-column type="selection" width="55"> </el-table-column>
      <el-table-column
        label="交款员"
        align="center"
        prop="tollCollector"
        :show-overflow-tooltip="true"
      />
      <el-table-column
        label="收费金额"
        align="center"
        prop="amountReceived"
        :show-overflow-tooltip="true"
      />
      <el-table-column
        label="退费金额"
        align="center"
        prop="refundAmount"
        :show-overflow-tooltip="true"
      />
      <el-table-column
        label="应交款"
        align="center"
        prop="payable"
        :show-overflow-tooltip="true"
      />
      <el-table-column
        label="交账时间"
        align="center"
        prop="createTime"
        :show-overflow-tooltip="true"
      />
      <el-table-column
        label="起止时间"
        align="center"
        prop="accountBeginTime"
        :show-overflow-tooltip="true"
      />
      <el-table-column
        label="截止时间"
        align="center"
        prop="accountEndTime"
        :show-overflow-tooltip="true"
      />
    </el-table>

    <div class="pag">
      <div class="pag1">
        <pagination
          v-show="total > 0"
          :total="total"
          :page.sync="queryParams.pageNum"
          :limit.sync="queryParams.pageSize"
          @pagination="getList"
        />
      </div>
    </div>

    <el-table
      :data="allList"
      style="margin-top: 60px; width: 80%"
      show-summary
      border
    >
      <el-table-column label="付款方式" align="center" prop="payType" />
      <el-table-column label="收费金额" align="center" prop="amountReceived">
      </el-table-column>
      <el-table-column label="退费金额" align="center" prop="refundAmount" />
      <el-table-column label="应交款" align="center" prop="payable" />
    </el-table>
  </div>
</template>
  
<script>
import { getNewDateList } from "@/api/hosp/order";
import {
  getcolllist,
  getdatalist,
  delById,
  getNewDate,
} from "@/api/hosp/water";
import { getInfo } from "@/api/login";
import moment from "moment";

export default {
  name: "Water",
  data() {
    return {
      pickerOptions: {
        shortcuts: [
          {
            text: "近一周",
            onClick(picker) {
              const end = new Date();
              const start = new Date();
              start.setTime(start.getTime() - 3600 * 1000 * 24 * 7);
              picker.$emit("pick", [start, end]);
            },
          },
          {
            text: "近一月",
            onClick(picker) {
              const end = new Date();
              const start = new Date();
              start.setTime(start.getTime() - 3600 * 1000 * 24 * 30);
              picker.$emit("pick", [start, end]);
            },
          },
          {
            text: "近三月",
            onClick(picker) {
              const end = new Date();
              const start = new Date();
              start.setTime(start.getTime() - 3600 * 1000 * 24 * 90);
              picker.$emit("pick", [start, end]);
            },
          },
        ],
      },
      // 遮罩层
      loading: true,
      tableData: [],
      selectList: [],
      allList: [],
      disabled: true,
      value1: [],
      CompanyList: [],
      // 选中数组
      dataList: [],
      time: "",
      id: "",
      tollCollectorId: "",
      // 非单个禁用
      single: true,
      closeList: 0,
      tollCollectorId: "",
      machiningTimeList: 0,
      debugTimeList: 0,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      item: "",
      userId: "",
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        tollCollectorName: null,
        payStasus: null,
        payType: null,
        deleted: null,
        customer: {
          cusName: null,
        },
        tollCollectorId: null,
        accountBeginTime: null,
        accountEndTime: null,
      },
      // 表单参数
      form: {},
    };
  },
  created() {
    this.getList();
    this.getCompanyList();
  },
  methods: {
    /** 查询体检流水列表 */
    getList() {
      getInfo().then((response) => {
        this.userId = response.user.userId;
        this.queryParams.tollCollectorName = response.user.nickName;
      });

      // getNewDate().then((response) => {
      //   if (response.code === 200) {
      //     this.value1 = [
      //       moment(response.data).format("YYYY-MM-DD 00:00:00"),
      //       moment(response.data).format("YYYY-MM-DD HH:mm:ss"),
      //     ];
      //   }
      // });
      getNewDateList().then((response) => {
        if (response.code === 200) {
          this.value1 = [
            moment(response.data).format("YYYY-MM-DD 00:00:00"),
            moment(response.data).format("YYYY-MM-DD 23:59:00"),
          ];
        }
      });

      // let data = {
      //   tollCollectorId: this.tollCollectorId,
      //   accountBeginTime: this.value1[0],
      //   accountEndTime: this.value1[1],
      //   pageNum: this.queryParams.pageNum,
      //   pageSize: this.queryParams.pageSize,
      // };
      // getcolllist(data).then((res) => {
      //   this.tableData = res.data.list;
      //   if (this.tableData.length === 0) {
      //     this.$message({
      //       message: '请搜索要撤销数据的时间段哦~',
      //       type: 'warning'
      //     });
      //   }
      //   if (res.code === 200) {
      //     if (this.tableData.length != 0) {
      //       this.$nextTick(() => {
      //         this.$refs.multipleTable.toggleRowSelection(
      //           this.tableData[0],
      //           true
      //         );
      //       });
      //     } else {
      //       this.$refs.multipleTable.clearSelection();
      //     }
      //   }

      //   // this.tableData.forEach(item => {
      //   //   this.allList = item.tjTollCollectorDetailList
      //   // })
      //   this.total = res.data.total;
      // });
    },
    // 选中下拉框Id
    idFn(value) {
      this.tollCollectorId = value;
    },
    // 下拉框显示
    getCompanyList() {
      this.loading = true;
      getdatalist().then((response) => {
        this.CompanyList = response.data;
        this.loading = false;
      });
    },

    // 搜索
    handleQuery() {
      let data = {
        tollCollectorId: this.tollCollectorId,
        accountBeginTime: this.value1[0],
        accountEndTime: this.value1[1],
        pageNum: this.queryParams.pageNum,
        pageSize: this.queryParams.pageSize,
      };
      getcolllist(data).then((res) => {
        this.tableData = res.data.list;
        this.allList = [];
        if (this.tableData.length != 0) {
          this.$nextTick(() => {
            this.$refs.multipleTable.toggleRowSelection(
              this.tableData[0],
              true
            );
          });
        } else {
          this.$refs.multipleTable.clearSelection();
        }
        // if (this.tableData.length > 0) {
        //   this.tableData.forEach(item => {
        //     this.allList = item.tjTollCollectorDetailList
        //   })
        // }else{
        //   this.allList = []
        // }
        this.total = res.data.total;
      });
    },
    handleUpdate() {},

    // 表格单选
    handleSelect(selection, val) {
      this.selectList = selection;
      this.dataList = this.$refs.multipleTable.selection;
      this.dataList.forEach((item) => {
        this.allList = item.tjTollCollectorDetailList;
        this.id = item.id;
        this.tollCollectorId = item.tollCollectorId;
      });
      if (selection.length > 1) {
        let del_row = selection.shift();
        this.$refs.multipleTable.toggleRowSelection(del_row, false);
      }
    },
    handledocument() {
      const viewNum = "809743614817824768";
      let accountId = this.selectList[0].accountId;
      const params = { viewNum, accountId };
      this.$tab.openPage("结账单", "/report/settlement", params);
    },
    tableRowClassName({ row, rowIndex }) {
      for (let i = 0; i < this.selectList.length; i++) {
        if (row === this.selectList[i]) {
          return "warning-row";
        }
      }
    },
    handleDelete() {
      let data = {
        id: this.id,
        tollCollectorId: this.tollCollectorId,
      };
      delById(data).then((res) => {
        this.$message({
          showClose: true,
          message: "该账单已成功撤销",
          type: "success",
        });
        this.getList();
        this.handleQuery();
      });
    },
  },
};
</script>
 
<style>
.el-table__header-wrapper .el-checkbox {
  display: none;
}

.el-date-editor--datetimerange.el-input,
.el-date-editor--datetimerange.el-input__inner {
  width: 100%;
}

.pag {
  width: 100%;
  display: flex;
  justify-content: center;
}

.pag1 {
  width: 30%;
}

.el-table__body tr.current-row > td {
  background-color: #f19944 !important;
  /* color: #f19944; */
  /* 设置文字颜色，可以选择不设置 */
}

.el-table .warning-row {
  background: #e5f3ff !important;
}
</style>